@@ -118,7 +118,7 @@ class LinuxDevice(object):
     '''
     A base class for common linux devices.
     '''
-    release = '1.1.18'
+    release = '1.1.20'
 
     LOG_EMERG = 0   # not used
     LOG_ALERT = 1   # not used
@@ -207,11 +207,12 @@ class LinuxDevice(object):
             #self.del__configure_interface()
             self._preconfig()
 
-        self["netdevice"] = self.release
-        if self["type"] == 'Linux':
-            tmp = copy.deepcopy(self.attributes)
-            tmp["password"] = "*******"
-            self.log("%s = %s\n" %(self.name, json.dumps(tmp, indent=4)))
+        self.log("welcome to netdevice %s, %s device %s.\n" %(self.release,
+            self["type"], self["hostname"]))
+        #if self["type"] == 'Linux':
+        #    tmp = copy.deepcopy(self.attributes)
+        #    tmp["password"] = "*******"
+        #    self.log("%s = %s\n" %(self.name, json.dumps(tmp, indent=4)))
 
         #self.x_get_interface()
         #self.log("interface = %s\n" %(json.dumps(self.interface, indent=4)))
@@ -281,8 +282,6 @@ class LinuxDevice(object):
             error = (i < len(prompt)) and prompt[i] or "None"
             self.log('Login failed: %s' %(error), color = "red")
             raise Exception ('Login failed: %s' %(error))
-        #self.log("succeed to %s %s.\n" %(self["scheme"], self["hostname"]), color = "green")
-        #self.log("succeed!", color = "green")
 
         if (self["type"] == 'Junos'):
             # Second phase
